// (C) Chistyakov T. S. 2008

{$apptype console}

uses
  SysUtils, Math;

var
  x, y: array of extended;
  
procedure err(code: integer; msg: string);
begin
  writeln(msg);
  halt(code);
end;

function cos(a, b, c: integer): extended;
var
  sp: extended;
begin
  sp :=
    (x[a] - x[b]) * (x[c] - x[b]) +
    (y[a] - y[b]) * (y[c] - y[b]);
  Result :=
    sp / (
      2 * Norm([x[a] - x[b], y[a] - y[b]]) *
      Norm([x[c] - x[b], y[c] - y[b]])
    );
end;

var
  fi, fo, fa: textfile;
  n, i: integer;
  a, b, c: integer;
  d, e, f: integer;
  co, ca: extended;
begin
  assignfile(fi, paramstr(1)); reset(fi);
  assignfile(fo, paramstr(2)); reset(fo);
  assignfile(fa, paramstr(3)); reset(fa);
  try
    try
      read(fi, n);
      setlength(x, n);
      setlength(y, n);
      for i := 0 to n - 1 do
        read(fi, x[i], y[i]);
      read(fo, a, b, c);
      read(fa, d, e, f);
      if not SeekEof(fo) then
        err(2, 'Unexpected characters in output file');
      if not SeekEof(fa) then
        err(3, 'Unexpected characters in answer file');
      if
        not InRange(a, 1, n) or
        not InRange(b, 1, n) or
        not InRange(c, 1, n)
      then
        err(1, 'Point index out of range in output file');
      if
        not InRange(d, 1, n) or
        not InRange(e, 1, n) or
        not InRange(f, 1, n)
      then
        err(3, 'Point index out of range in answer file');
      if (a = b) or (b = c) or (c = a) then
        err(1, 'Some points are equal in output file');
      if (d = e) or (e = f) or (f = d) then
        err(3, 'Some points are equal in answer file');
      Dec(a); Dec(b); Dec(c);
      Dec(d); Dec(e); Dec(f);
      co := cos(a, b, c);
      ca := cos(d, e, f);
      if Abs(ca - co) > 1e-10 then
        if (ca < co) then
          err(1, format('Non-optimal angle found: cos diff = %e', [abs(co-ca)]))
        else
          err(3, format('Answer is worse: cos diff = %e', [abs(co-ca)]));
      WriteLn(format('OK: cos diff = %e', [abs(co-ca)]));
    except
      on E: Exception do begin
        WriteLn(E.Message);
        Halt(2);
      end;
    end;
  finally
    closefile(fi);
    closefile(fo);
    closefile(fa);
  end;
end.