/**
 *
 * @author Zhuplev Anton
 */
import java.io.*;
import java.util.*;



public class generator implements Runnable {


  private String output = "input.txt";
  private PrintWriter out = null;
  private String[] args;

  public generator(String[] args) {
    try {
      this.args = args;
      out = new PrintWriter(new File(output));
    } catch (Exception exept) {
      exept.printStackTrace();
      System.exit(1);
    }
  }


  public static void main(String[] args) {
    Locale.setDefault(Locale.US);
    new Thread(new generator(args)).start();
  }


  public void run() {
    try {
      if (args.length != 3) {
        throw new Exception("Invalid arguments.\n" +
                "Use following: n, x/y bound, randseed");
      }
      int argsInt[] = new int[args.length];
      for (int i = 0; i < args.length; i++) {
        argsInt[i] = Integer.parseInt(args[i]);
      }
      solve(argsInt);
    } catch (Exception exept) {
      exept.printStackTrace();
      System.exit(1);
    } finally {
      out.close();
    }
  }


  private void myAssert(boolean expr, String message) {
    if (!expr) {
      throw new Error("Assertion failure!!! " + message);
    }
  }


  @SuppressWarnings("unchecked")
  private void solve(int[] args) {
    Point.createRandom(args[2]);
    int n = args[0];
    TreeSet<LineEquation> les = new TreeSet<LineEquation>();
    TreeSet<Point> pointList = new TreeSet<Point>();
    long op = 0;
    for (int i = 0; i < n; i++) {
      Point newPoint;
      boolean isOnLine = false;
      do {
        isOnLine = false;
        op++;
        myAssert(op < 1000*1000, "Your params is not good. Lots of operations's been done, " +
                "but solution has not been found.");
        newPoint = Point.genRandom(args[1], args[1]);
        if (pointList.contains(newPoint)) {
          isOnLine = true;
          continue;
        }
        Iterator<Point> it = pointList.iterator();
        while (it.hasNext()) {
          Point curr = it.next();
          if (les.contains(new LineEquation(curr, newPoint))) {
            isOnLine = true;
            break;
          }
        }
      } while (isOnLine);
      Iterator<Point> it = pointList.iterator();
      while (it.hasNext()) {
        Point curr = it.next();
        les.add(new LineEquation(curr, newPoint));
      }
      pointList.add(newPoint);
    }
    myAssert(n == pointList.size(), "n is not equals to pointList length");

    int cnt = 0;
    Point[] list = new Point[n];
    Iterator<Point> it = pointList.iterator();
    while (it.hasNext()) {
      list[cnt++] = it.next();
    }
    Random random = new Random(args[2]);
    for (int i = 0; i < n*n; i++) {
      int a = random.nextInt(list.length);
      int b = random.nextInt(list.length);
      Point t = list[a];
      list[a] = list[b];
      list[b] = t;
    }
    for (int i = 0; i < n; i++) {
      int a = random.nextInt(list.length);
      int b = 0;
      Point t = list[a];
      list[a] = list[b];
      list[b] = t;
    }

    out.println(n);
    for (Point p : list) {
      out.format("%d %d\n", p.getX(), p.getY());
    }
  }
}



class LineEquation implements Comparable {

  private long a, b, c;


  public LineEquation(Point a, Point b) {
    this.a = b.getY() - a.getY();
    this.b = a.getX() - b.getX();
    this.c = a.getY()*b.getX() - a.getX()*b.getY();
    long sign = this.a < 0 ? -1 : 1;
    long k = gcd(gcd(Math.abs(this.a), Math.abs(this.b)), Math.abs(this.c));
    this.a = sign * this.a / k;
    this.b = sign * this.b / k;
    this.c = sign * this.c / k;
  }

  public static long gcd(long a, long b) {
    while (b != 0) {
      long t = a;
      a = b;
      b = t % b;
    }
    return a;
  }

  public int compareTo(Object ol) {
    if (!(ol instanceof LineEquation))
      throw new ClassCastException("A LineEquation object expected.");
    LineEquation l = (LineEquation)ol;
    if (a == l.a && b == l.b && c == l.c) {
      return 0;
    } else {
      if (a != l.a) {
        return a < l.a ? -1 : 1;
      }
      if (b != l.b) {
        return b < l.b ? -1 : 1;
      }
      return c < l.c ? -1 : 1;
    }
  }
}



class Point implements Comparable {

  private long x, y;
  private static Random random = new Random();


  public static Point genRandom(int xb, int yb) {
    return new Point(random.nextInt(2*xb+1) - xb, random.nextInt(2*yb+1) - yb);
  }


  public static void createRandom(long randseed) {
    random = new Random(randseed);
  }


  public Point(long x, long y) {
    this.x = x;
    this.y = y;
  }


  public long getX() {
    return x;
  }


  public long getY() {
    return y;
  }

  public int compareTo(Object op) throws ClassCastException {
    if (!(op instanceof Point))
      throw new ClassCastException("A Point object expected.");
    Point p = (Point)op;
    if (x == p.x && y == p.y) {
      return 0;
    }
    return (x < p.x || x == p.x && y < p.y) ? -1 : 1;
  }
}
